import { ValidationMessage } from '../models/validationMessage';
import { EventEmitter, Output } from '@angular/core';
import { Subject } from 'rxjs/Subject';
import MessageType from '../models/messageType';
/**
 * @abstract
 */
var BasePage = (function () {
    /**
     * @param {?} mediator
     * @param {?} componentName
     * @param {?} pageHeader
     * @param {?} pageSubHeader
     */
    function BasePage(mediator, componentName, pageHeader, pageSubHeader) {
        this.mediator = mediator;
        this.componentName = componentName;
        this.pageHeader = pageHeader;
        this.pageSubHeader = pageSubHeader;
        this.messagesReceived = new EventEmitter();
        this.receivedMessages = new Subject();
    }
    /**
     * @return {?}
     */
    BasePage.prototype.showSuccess = function () {
        this.showInfo("Your Changes were saved");
    };
    /**
     * @param {?} message
     * @return {?}
     */
    BasePage.prototype.showInfo = function (message) {
        this.messagesReceived.emit([new ValidationMessage(MessageType.Info, "", message)]);
    };
    /**
     * @param {?} message
     * @return {?}
     */
    BasePage.prototype.showWarning = function (message) {
        this.messagesReceived.emit([new ValidationMessage(MessageType.Warning, "", message)]);
    };
    /**
     * @param {?} message
     * @return {?}
     */
    BasePage.prototype.showError = function (message) {
        this.messagesReceived.emit([new ValidationMessage(MessageType.Error, "", message)]);
    };
    /**
     * @param {?} message
     * @return {?}
     */
    BasePage.prototype.showException = function (message) {
        this.messagesReceived.emit([new ValidationMessage(MessageType.Exception, "", message)]);
    };
    /**
     * @template U
     * @param {?} query
     * @return {?}
     */
    BasePage.prototype.query = function (query) {
        var _this = this;
        return this.mediator.query(query)
            .then(function (res) {
            var /** @type {?} */ result = (res);
            _this.messagesReceived.emit(result.ValidationMessages);
            return (res);
        }, function (res) {
            var /** @type {?} */ result = (res);
            _this.messagesReceived.emit(result.ValidationMessages);
            return (res);
        });
    };
    /**
     * @template U
     * @param {?} command
     * @return {?}
     */
    BasePage.prototype.command = function (command) {
        var _this = this;
        return this.mediator.command(command)
            .then(function (res) {
            var /** @type {?} */ result = (res);
            _this.messagesReceived.emit(result.ValidationMessages);
            return (res);
        }, function (res) {
            var /** @type {?} */ result = (res);
            _this.messagesReceived.emit(result.ValidationMessages);
            return (res);
        });
    };
    BasePage.propDecorators = {
        'messagesReceived': [{ type: Output },],
        'receivedMessages': [{ type: Output },],
    };
    return BasePage;
}());
export { BasePage };
function BasePage_tsickle_Closure_declarations() {
    /** @type {?} */
    BasePage.propDecorators;
    /** @type {?} */
    BasePage.prototype.messagesReceived;
    /** @type {?} */
    BasePage.prototype.receivedMessages;
    /** @type {?} */
    BasePage.prototype.mediator;
    /** @type {?} */
    BasePage.prototype.componentName;
    /** @type {?} */
    BasePage.prototype.pageHeader;
    /** @type {?} */
    BasePage.prototype.pageSubHeader;
}
//# sourceMappingURL=basePage.js.map