var Dictionary = (function () {
    function Dictionary() {
        this.keysInternal = [];
        this.valuesInternal = [];
        this.undefinedKeyErrorMessage = "Key is either undefined, null or an empty string.";
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    Dictionary.prototype.add = function (key, value) {
        var _this = this;
        var /** @type {?} */ addAction = function (k, v) {
            if (_this.containsKey(k)) {
                throw new Error("An element with the same key already exists in the dictionary.");
            }
            _this.keysInternal.push(k);
            _this.valuesInternal.push(v);
        };
        this.checkKeyAndPerformAction(addAction, key, value);
    };
    /**
     * @param {?} key
     * @return {?}
     */
    Dictionary.prototype.remove = function (key) {
        var _this = this;
        var /** @type {?} */ removeAction = function (k) {
            if (!_this.containsKey(k)) {
                return false;
            }
            var /** @type {?} */ index = _this.keysInternal.indexOf(k);
            _this.keysInternal.splice(index, 1);
            _this.valuesInternal.splice(index, 1);
            return true;
        };
        return ((this.checkKeyAndPerformAction(removeAction, key)));
    };
    /**
     * @param {?} key
     * @return {?}
     */
    Dictionary.prototype.getValue = function (key) {
        var _this = this;
        var /** @type {?} */ getValueAction = function (k) {
            if (!_this.containsKey(k)) {
                return null;
            }
            var /** @type {?} */ index = _this.keysInternal.indexOf(k);
            return _this.valuesInternal[index];
        };
        return (this.checkKeyAndPerformAction(getValueAction, key));
    };
    /**
     * @param {?} key
     * @return {?}
     */
    Dictionary.prototype.containsKey = function (key) {
        var _this = this;
        var /** @type {?} */ containsKeyAction = function (k) {
            if (_this.keysInternal.indexOf(k) === -1) {
                return false;
            }
            return true;
        };
        return (this.checkKeyAndPerformAction(containsKeyAction, key));
    };
    /**
     * @param {?} key
     * @param {?} newValue
     * @return {?}
     */
    Dictionary.prototype.changeValueForKey = function (key, newValue) {
        var _this = this;
        var /** @type {?} */ changeValueForKeyAction = function (k, nv) {
            if (!_this.containsKey(k)) {
                throw new Error("In the dictionary there is no element with the given key.");
            }
            var /** @type {?} */ index = _this.keysInternal.indexOf(k);
            _this.valuesInternal[index] = nv;
        };
        this.checkKeyAndPerformAction(changeValueForKeyAction, key, newValue);
    };
    /**
     * @return {?}
     */
    Dictionary.prototype.keys = function () {
        return this.keysInternal;
    };
    /**
     * @return {?}
     */
    Dictionary.prototype.values = function () {
        return this.valuesInternal;
    };
    /**
     * @return {?}
     */
    Dictionary.prototype.count = function () {
        return this.valuesInternal.length;
    };
    /**
     * @param {?} object
     * @return {?}
     */
    Dictionary.prototype.isEitherUndefinedNullOrStringEmpty = function (object) {
        return (typeof object) === "undefined" || object === null || object.toString() === "";
    };
    /**
     * @param {?} action
     * @param {?} key
     * @param {?=} value
     * @return {?}
     */
    Dictionary.prototype.checkKeyAndPerformAction = function (action, key, value) {
        if (this.isEitherUndefinedNullOrStringEmpty(key)) {
            throw new Error(this.undefinedKeyErrorMessage);
        }
        return action(key, value);
    };
    return Dictionary;
}());
export { Dictionary };
function Dictionary_tsickle_Closure_declarations() {
    /** @type {?} */
    Dictionary.prototype.keysInternal;
    /** @type {?} */
    Dictionary.prototype.valuesInternal;
    /** @type {?} */
    Dictionary.prototype.undefinedKeyErrorMessage;
}
//# sourceMappingURL=dictionary.js.map