import { Injectable } from '@angular/core';
import { ConfigService } from './config-service';
import { AuthTokenResolver } from './AuthTokenResolver';
import { HttpClient, HttpHeaders } from '@angular/common/http';
var Mediator = (function () {
    /**
     * @param {?} http
     * @param {?} configService
     * @param {?} tokenResolver
     */
    function Mediator(http, configService, tokenResolver) {
        this.http = http;
        this.configService = configService;
        this.tokenResolver = tokenResolver;
        this.commandEndpoint = configService.config.commandEndpoint;
        this.queryEndpoint = configService.config.queryEndpoint;
    }
    /**
     * @template U
     * @param {?} query
     * @return {?}
     */
    Mediator.prototype.query = function (query) {
        var _this = this;
        var /** @type {?} */ url = this.getQueryUrl(query) + '?' + this.getAsUriParameters(query, '');
        return this.tokenResolver.getToken(this.queryEndpoint).then(function (token) { return _this.doQuery(query, url, token); });
    };
    /**
     * @template U
     * @param {?} command
     * @return {?}
     */
    Mediator.prototype.command = function (command) {
        var _this = this;
        var /** @type {?} */ url = this.getCommandUrl(command);
        return this.tokenResolver.getToken(this.commandEndpoint).then(function (token) { return _this.doCommand(command, url, token); });
    };
    /**
     * @template U
     * @param {?} query
     * @param {?} url
     * @param {?} token
     * @return {?}
     */
    Mediator.prototype.doQuery = function (query, url, token) {
        return this.http
            .get(url, {
            headers: this.getHeaders(token)
        })
            .toPromise();
    };
    /**
     * @template U
     * @param {?} command
     * @param {?} url
     * @param {?} token
     * @return {?}
     */
    Mediator.prototype.doCommand = function (command, url, token) {
        return this.http
            .post(url, command, { headers: this.getHeaders(token) })
            .toPromise();
    };
    /**
     * @param {?} object
     * @return {?}
     */
    Mediator.prototype.objectToParams = function (object) {
        var /** @type {?} */ params = new URLSearchParams();
        for (var _i = 0, _a = Object.keys(object); _i < _a.length; _i++) {
            var key = _a[_i];
            if (!object.hasOwnProperty(key) || this.isEndPoint(key)) {
                continue;
            }
            params.set(key, JSON.stringify(object[key]));
        }
        return params;
    };
    /**
     * @param {?} data
     * @param {?} keyPreprend
     * @return {?}
     */
    Mediator.prototype.getAsUriParameters = function (data, keyPreprend) {
        var _this = this;
        return Object.keys(data).map(function (k) {
            if (data[k] == null) {
                return '';
            }
            if (Array.isArray(data[k])) {
                var /** @type {?} */ keyE_1 = keyPreprend + encodeURIComponent(k + '[]');
                return data[k].map(function (subData) { return keyE_1 + '=' + encodeURIComponent(subData); }).join('&');
            }
            if (typeof data[k] === 'object') {
                console.log(data[k]);
                if (Object.keys(data[k]) == null) {
                    return null;
                }
                return _this.getAsUriParameters(data[k], k + '.');
            }
            return keyPreprend + encodeURIComponent(k) + '=' + encodeURIComponent(data[k]);
        }).join('&');
    };
    /**
     * @template U
     * @param {?} command
     * @return {?}
     */
    Mediator.prototype.getCommandUrl = function (command) {
        return this.commandEndpoint + "/" + command.endpointName;
    };
    /**
     * @template U
     * @param {?} query
     * @return {?}
     */
    Mediator.prototype.getQueryUrl = function (query) {
        return this.queryEndpoint + "/" + query.endpointName;
    };
    /**
     * @param {?} token
     * @return {?}
     */
    Mediator.prototype.getHeaders = function (token) {
        var /** @type {?} */ headers = new HttpHeaders({ 'Content-Type': 'application/json' });
        if (this.tokenResolver.isEnabled) {
            headers.append('Authorization', 'Bearer ' + token);
        }
        return headers;
    };
    /**
     * @param {?} key
     * @return {?}
     */
    Mediator.prototype.isEndPoint = function (key) {
        return key === 'endpointName'
            || key === 'typescriptPlace';
    };
    Mediator.decorators = [
        { type: Injectable },
    ];
    /**
     * @nocollapse
     */
    Mediator.ctorParameters = function () { return [
        { type: HttpClient, },
        { type: ConfigService, },
        { type: AuthTokenResolver, },
    ]; };
    return Mediator;
}());
export { Mediator };
function Mediator_tsickle_Closure_declarations() {
    /** @type {?} */
    Mediator.decorators;
    /**
     * @nocollapse
     * @type {?}
     */
    Mediator.ctorParameters;
    /** @type {?} */
    Mediator.prototype.commandEndpoint;
    /** @type {?} */
    Mediator.prototype.queryEndpoint;
    /** @type {?} */
    Mediator.prototype.http;
    /** @type {?} */
    Mediator.prototype.configService;
    /** @type {?} */
    Mediator.prototype.tokenResolver;
}
//# sourceMappingURL=mediator.js.map